import logging
from atgateway.app.sensing_mgr.model_dev_base import ModelDevBase
from atgateway.app.sensing_mgr.const import Const
from .reporters.adc_reporter import ADCReporter


class ModelDevA6EBase(ModelDevBase):
    def __init__(self, modelConfig, cloud_config, send_cloud):
        super().__init__(modelConfig, send_cloud)
        self._adc_reporter = None
        self._model_config = modelConfig
        self._cloud_config = cloud_config
        self._logging = logging.getLogger(Const.LOGGER_NAME)

    def on_recv_data(self, data):
        if data is None:
            self._logging.info("data from cloud is empty.")
            return False

        if self._cloud_config:
            self._logging.info("update config from cloud.")
            self.update_reporter(self._model_config, data)
        else:
            self._logging.info("config don't update from cloud.")

        return

    def update_reporter(self, config, data):
        update_list = config.update_config(data)

        if not update_list:
            return

        for section, conf in update_list.items():
            if section == config.ADC:
                self._adc_reporter.set_interval(conf.get(config.POLLING_INTERVAL))

    def send_interval(self, config):
        conf = config.get_default_conf()
        return conf.get(config.SEND_INTERVAL)

    def _make_active_reporters(self, config, report_queue, report_repository):
        reporters = []
        return reporters

    def _make_reporters(self, config):
        reporters = []
        conf = config.get_adc_conf()

        adcReporter = ADCReporter(
            start=True,
            interval=conf.get(config.POLLING_INTERVAL)
            )
        adcReporter.set_interval(conf.get(config.POLLING_INTERVAL))
        reporters.append(adcReporter)
        self._adc_reporter = adcReporter
        return reporters

#
# End of File
#
