import logging
from atgateway.app.sensing_mgr.const import Const
from atgateway.app.sensing_mgr.modules.lib.reporter import Reporter
from atgateway.app.sensing_mgr.modules.lib.report import Report


class ADCReporter(Reporter):
    def __init__(self, start, interval):
        super().__init__()
        self._prop = {}
        self._prop["ADC_polling_interval"] = interval

        self._oneshot = False
        self._oneshot_send = False
        self._start = start
        self._logging = logging.getLogger(Const.LOGGER_NAME)

    def data_type(self):
        return 'adc_value'

    def oneshot_report(self):
        self._oneshot = True

    def report(self):
        report = None

        if self._start is False:
            return (report, None)
        if self._oneshot is False or \
                (self._oneshot is True and self._oneshot_send is False):
            value = None
            try:
                with open('/sys/bus/iio/devices/iio:device0/in_voltage1_raw') as file:
                    value = int(file.read())
            except Exception as e:
                self._logging.error("ADC value read error.")
                self._logging.error(e.args)

            report = Report.report_now(
                'measurement',
                ADC_value=value
            )
            self._oneshot_send = True
        return (report, None)

#
# End of File
#
